#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.3.5
id: xml-conduit-1.3.5-b0d7925ea0f1a62fe18b3cdd25dd3416
key: xmlco_12KN28fUTcDAD9RoetZ0KS
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
exposed: True
exposed-modules:
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
    Text.XML.Cursor Text.XML.Cursor.Generic Text.XML
hidden-modules: Text.XML.Stream.Token
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-conduit-1.3.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-conduit-1.3.5
hs-libraries: HSxml-conduit-1.3.5-12KN28fUTcDAD9RoetZ0KS
depends:
    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
    conduit-extra-1.1.13.1-cf2e2742d7d01907ed25c65d155b9a5e
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    xml-types-0.3.6-d2b0c720c0578e3ecc104b3af950ac90
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
